#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-language-server
version:              2.2.0.0
visibility:           public
id:                   haskell-language-server-2.2.0.0-EAk7P9iv96i6k8I5E1vAD9
key:                  haskell-language-server-2.2.0.0-EAk7P9iv96i6k8I5E1vAD9
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             LSP server for GHC
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  c5b28539fb883e2e2027d7818e22b93c
exposed:              True
exposed-modules:      HlsPlugins Ide.Arguments Ide.Main Ide.Version
hidden-modules:       Paths_haskell_language_server
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.2.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.2.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.2.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-server
hs-libraries:         HShaskell-language-server-2.2.0.0-EAk7P9iv96i6k8I5E1vAD9
depends:
    aeson-pretty-0.8.10-9DzuE6K5ualIh936UucCql
    async-2.2.5-H7c59317Mex2thAVLk9lLr base-4.18.2.1
    base16-bytestring-1.0.2.0-IGYxLdp0ecpAQ2JsWo9qAZ
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-FOefCbIw1kEnRAQHP7vgX
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    extra-1.7.16-AZZkJf8uXcBmNBZ3QBrWg filepath-1.4.300.1 ghc-9.6.6
    ghcide-2.2.0.0-A7bgaULCXeX9IRF5j2vaTv
    githash-0.1.6.3-4ToVL1l9WaF7nAaGLv1EIY
    hie-bios-0.12.0-GCmUN61rxns7gfz3bLC7i3
    hiedb-0.4.3.0-1gIpt5OtqZPJypGvKHlhZR
    hls-alternate-number-format-plugin-2.2.0.0-Fh7un7g4OuoEhzMqmlzb5c
    hls-cabal-fmt-plugin-2.2.0.0-JBlMMAnv1PxLXpb2mttcY5
    hls-cabal-plugin-2.2.0.0-7rfl9BLhacQKG01si1OaoD
    hls-call-hierarchy-plugin-2.2.0.0-7exwLdy3Way7Qsi4qMUhly
    hls-change-type-signature-plugin-2.2.0.0-81mTnp73YV020nFgr6qSs
    hls-class-plugin-2.2.0.0-4xFsy1RiCbSFVpZRXy3pKp
    hls-code-range-plugin-2.2.0.0-FBBh70UHtQl7G85nD9tyHm
    hls-eval-plugin-2.2.0.0-B4UyKwFYpQmCjVMT7TWrOm
    hls-explicit-fixity-plugin-2.2.0.0-3xV5ECSIN7YJutrTFYKIUB
    hls-explicit-imports-plugin-2.2.0.0-4QZkbGnrdBKLOAT6RLjjdg
    hls-explicit-record-fields-plugin-2.2.0.0-5KOuNP1nTLMHdGJQaKZsA2
    hls-fourmolu-plugin-2.2.0.0-IWBfGtG9Q3i3qHcF0GnefC
    hls-gadt-plugin-2.2.0.0-GEcvFT2zt2OHO0ruPWrmCu
    hls-graph-2.2.0.0-Kv1SctUIRq7IoOkuFnI2jo
    hls-hlint-plugin-2.2.0.0-23jK0CRw9jT5HMuXu51dre
    hls-module-name-plugin-2.2.0.0-C66pT50cDRlBVnlIk2vTDp
    hls-ormolu-plugin-2.2.0.0-AGfZlvLrLEcHMDnFOsYPZB
    hls-overloaded-record-dot-plugin-2.2.0.0-G0cUxpkQWm3EVUYoZ8sxv
    hls-plugin-api-2.2.0.0-CJlumqKcZFmEjFCUieU5XS
    hls-pragmas-plugin-2.2.0.0-H4s2QqLIy52B8yjvrsXxI6
    hls-qualify-imported-names-plugin-2.2.0.0-7SoQ2xQzvKhK0rfeCS3RN3
    hls-refactor-plugin-2.2.0.0-JjcgmX92bbe4YQJFnGNjdo
    hls-rename-plugin-2.2.0.0-979135V3Q1I0bzldiP5ON
    hls-retrie-plugin-2.2.0.0-8uCMvV6Sp5966crlodGRxm
    hls-splice-plugin-2.2.0.0-2Q9dnvNA0lMXmWL4aTc6H
    hls-stylish-haskell-plugin-2.2.0.0-LHczrL3plY78Rz5Qg8RBPf
    lsp-2.2.0.0-CukKTvdVHsT6La4UfPeciM
    optparse-applicative-0.18.1.0-4BezxXoHIckIHconhtKlD7
    optparse-simple-0.1.1.4-DpE9WC7eTOnA3ART1h58ZA
    prettyprinter-1.7.1-Egfz8R6Hy2931hrqdwzdET process-1.6.19.0
    safe-exceptions-0.1.7.4-AkFQpeQZgUZ5VDqbpLWXE4
    sqlite-simple-0.4.19.0-lipRxY5ORULaWstgmJR0P text-2.0.2
    unordered-containers-0.2.20.1-KjVwmKBzsCnE6cNwSXaI5c

haddock-interfaces:
    /usr/share/doc/haskell-language-server/html/haskell-language-server.haddock

haddock-html:         /usr/share/doc/haskell-language-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

